"use client"

import { Button } from "@/components/ui/button";
import { Form, FormControl, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { useForm } from "react-hook-form";
import { signIn } from "next-auth/react";
import { useRouter } from "next/navigation";
import { zodResolver } from "@hookform/resolvers/zod"
import { useToast } from "@/components/ui/use-toast"
import { Toaster } from "@/components/ui/toaster";
import Link from "next/link";
import { z } from "zod";
import { Checkbox } from "@/components/ui/checkbox";


export default function Cadastro() {

  const router = useRouter();

  const { toast } = useToast();

  const formSchema = z.object({
    nome: z.string({ required_error: "Nome é obrigatório" }),
    email: z.string({ required_error: "E-mail é obrigatório" }).email({ message: "E-mail inválido !" }),
    ocupacao: z.string({ required_error: "Ocupação é obrigatório" }),

    senha: z.string({ required_error: "Senha é obrigatória" }).min(8, { message: "Deve ter no mínimo 8 caracteres !" }),
    confirmarsenha: z.string({ required_error: "Senha é obrigatória" }).min(8, { message: "Deve ter no mínimo 8 caracteres !" }),
    termos: z.boolean({ required_error: "termos é obrigatório" }).default(false),
  })

  const form = useForm({
    resolver: zodResolver(formSchema)
  })

  async function cadastrar(data) {

    // const response = await signIn("credentials", {
    //   email: data.email,
    //   senha: data.senha,
    //   redirect: false
    // })

    if (response.ok && !response.error) {
      console.log(response)
    } else {

      let message = "";

      switch (response.error) {
        case "fetch failed":
          message = "Servidor fora do ar, contate o Administrador !"
          break;
        case "CredentialsSignin":
          message = "E-mail ou senha inválida !"
          break;
        default:
          message = "Erro ao capturar mensagem do servidor, contate o Administrador !"
      }

      toast({
        title: (
          <p className="text-red-700">{message}</p>
        )
      })

    }
  }

  return (
    <>

      <main className="w-full h-auto flex justify-center items-center">

        <div className="flex flex-row justify-center w-[50%] h-auto m-[5rem]">

          <div className="w-full flex flex-col gap-[1rem] max-w-[28rem]">

            <h1 className="text-4xl font-bold">Cadastre uma conta</h1>

            <p className="text-2xl">Cadastre-se para discutir</p>

            <Form {...form}>
              <form className="w-full flex flex-col gap-[1rem]" onSubmit={form.handleSubmit(cadastrar)}>

                <FormField
                  control={form.control}
                  name="nome"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel htmlFor="nome">Nome:</FormLabel>
                      <FormControl>
                        <Input
                          name="nome"
                          type="nome"
                          id="nome"
                          placeholder="Nome do usuário"
                          {...field}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />

                <FormField
                  control={form.control}
                  name="email"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel htmlFor="email">E-mail:</FormLabel>
                      <FormControl>
                        <Input
                          name="email"
                          type="email"
                          id="email"
                          placeholder="usuario@gmail.com"
                          {...field}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />

                <FormField
                  control={form.control}
                  name="ocupacao"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel htmlFor="ocupação">Ocupação:</FormLabel>
                      <FormControl>
                        <Input
                          name="ocupacao"
                          type="ocupacao"
                          id="ocupacao"
                          placeholder="Ocupação"
                          {...field}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />

                <FormField
                  control={form.control}
                  name="senha"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel htmlFor="senha">Senha:</FormLabel>
                      <FormControl>
                        <Input
                          name="senha"
                          type="password"
                          id="senha"
                          placeholder="********"
                          {...field}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />

                <FormField
                  control={form.control}
                  name="confirmarsenha"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel htmlFor="confirmarsenha">Confirmar senha:</FormLabel>
                      <FormControl>
                        <Input
                          name="confirmarsenha"
                          type="password"
                          id="confirmarsenha"
                          placeholder="********"
                          {...field}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />

                <FormField
                  control={form.control}
                  name="termos"
                  render={({ field }) => (
                    <FormItem>
                      <FormControl>

                        <div className="items-top flex space-x-2 ">
                          <Checkbox id="terms1"/>
                          <div className="grid gap-1.5 leading-none ">
                            <label
                              htmlFor="terms1"
                              className="text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70"
                            >
                              Aceita termos e Condições?
                            </label>
                            <p className="text-sm text-muted-foreground ">
                            Você concorda com nossos Termos de Serviço e Política de Privacidade.                            </p>
                          </div>
                        </div>
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />

                <div className="flex flex-col justify-center items-center gap-[2rem] mt-[2rem] ">


                <Button
                  data-test="btnCadastrar"
                  type="submit"
                  className="w-full bg-primaryColor hover:bg-primaryDark "
                > 
                Cadastrar  
                 </Button>
            

                </div>

              </form>
            </Form>

          </div>

          <div className="flex flex-col justify-center items-center">
          <img src="/img/BNCC.png" className="" alt="BNCC" title="BNCC" />
          <h1 className="text-2xl">Plataforma</h1>
          <h1 className="text-2xl">Discussão</h1>
          <h1 className="text-2xl">BNCC</h1>
        </div>
        </div>

      </main>

    </>
  )
}