"use client"

import { Button } from "@/components/ui/button";
import { Form, FormControl, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { useForm } from "react-hook-form";
import { signIn } from "next-auth/react";
import { useRouter } from "next/navigation";
import { zodResolver } from "@hookform/resolvers/zod"
import { useToast } from "@/components/ui/use-toast"
import { Toaster } from "@/components/ui/toaster";
import Link from "next/link";
import { z } from "zod";


export default function Login() {

  const router = useRouter();

  const { toast } = useToast();

  const formSchema = z.object({
    email: z.string({ required_error: "E-mail é obrigatório" }).email({ message: "E-mail inválido !" }),
    senha: z.string({ required_error: "Senha é obrigatória" }).min(8, { message: "Deve ter no mínimo 8 caracteres !" })
  })

  const form = useForm({
    resolver: zodResolver(formSchema)
  })

  async function logar(data) {

    const response = await signIn("credentials", {
      email: data.email,
      senha: data.senha,
      redirect: false
    })

    if (response.ok && !response.error) {
      console.log(response)
    } else {

      let message = "";

      switch (response.error) {
        case "fetch failed":
          message = "Servidor fora do ar, contate o Administrador !"
          break;
        case "CredentialsSignin":
          message = "E-mail ou senha inválida !"
          break;
        default:
          message = "Erro ao capturar mensagem do servidor, contate o Administrador !"
      }

      toast({
        title: (
          <p className="text-red-700">{message}</p>
        )
      })

    }
  }


  return (
    <main className="w-full h-auto flex justify-center items-center">
      <Toaster />
      <div className="flex flex-row justify-center w-[50%] h-auto m-[5rem]">
        <div className="w-full flex flex-col gap-[1rem] max-w-[28rem]">

          <h1 className="text-4xl font-bold">Bem-vindo(a)</h1>

          <p className="text-2xl">Entre para discutir</p>

          <Form {...form}>
            <form onSubmit={form.handleSubmit(logar)}>
              <FormField
                control={form.control}
                name="email"
                render={({ field }) => (
                  <FormItem>
                    <FormLabel htmlFor="email">E-mail:</FormLabel>
                    <FormControl>
                      <Input
                        name="email"
                        type="email"
                        id="email"
                        placeholder="usuario@gmail.com"
                        {...field}
                      />
                    </FormControl>
                    <FormMessage />
                  </FormItem>
                )}
              />

              <FormField
                control={form.control}
                name="senha"
                render={({ field }) => (
                  <FormItem>
                    <FormLabel htmlFor="senha">Senha:</FormLabel>
                    <FormControl>
                      <Input
                        name="senha"
                        type="password"
                        id="senha"
                        placeholder="********"
                        {...field}
                      />
                    </FormControl>
                    <FormMessage />
                  </FormItem>
                )}
              />

              <div className="flex flex-col justify-center items-center gap-[2rem] mt-[2rem]">

                <Button
                  data-test="btnEntrar"
                  type="submit"
                  className="w-full bg-primaryColor hover:bg-primaryDark "
                >
                  Entrar
                </Button>
              </div>

              <div className="flex flex-col  gap-[2rem] mt-[2rem]">
                <p className="">Ainda não tem uma conta?       
                  <Link className="underline text-sky-400" href="/cadastro">Cadastrar</Link>
                </p> 
                
                 <Link className="no-underline hover:underline" href="/recuperarsenha">Esqueci minha senha ?</Link>
              </div>

              
                {/*<Link className="w-full" href="/cadastro"> 
                
                <Button
                  data-test="btnCadastrar"
                  type="button"
                  className="bg-primaryColor hover:bg-primaryDark "
                > 
                Cadastrar  
                 </Button>
                 </Link> */}

            </form>
          </Form>
        </div>

        <div className="flex flex-col justify-center items-center">
          <img src="/img/BNCC.png" className="" alt="BNCC" title="BNCC" />
          <h1 className="text-2xl">Plataforma</h1>
          <h1 className="text-2xl">Discussão</h1>
          <h1 className="text-2xl">BNCC</h1>
        </div>

      </div>

    </main>
  )
}