import NextAuth from "next-auth";
import CredentialsProvider from "next-auth/providers/credentials";
import { cookies } from "next/headers";

const authOptions = {
  providers: [
    CredentialsProvider({
      name: "credentials",
      credentials: {
        email: { label: "E-mail:", type: "text" },
        senha: { label: "Senha:", type: "password" }
      },

      async authorize(credentials, req) {
        const response = await fetch(`${process.env.API_URL}/login`, {
          method: "POST",
          headers: {
            "Content-Type": "application/json"
          },
          body: JSON.stringify({
            email: credentials.email, senha: credentials.senha
          })
        })

        const data = await response.json()

        if (data?.user) {
          cookies().set("next-auth.requestToken", data.token);
            
          return data.user;
        }

        return null;
      }
    })
  ],
  
  pages: {
    signIn: "/"
  },
  
  callbacks: {
    async jwt({ token, user }) {
      user && (token.user = user);
      return token;
    },
    async session({ session, token }) {
      token && (session = token.user);
      return session;
    }
  }
}
const handler = NextAuth(authOptions);

export { handler as GET, handler as POST, authOptions }; 
